==> libphidget22-1.0.0.20171120.tar.gz: libphidget22-1.0.0.20171120/src/vintpackets.gen.c <==

static const VINTIO_t VINTIO[] = {
	{ _sendDEFAULT, _recvDEFAULT },	/* 0 */
	{ _sendDEFAULT, _recvDEFAULT },	/* 1 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 2 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 3 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 4 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 5 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 6 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 7 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 8 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 9 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 10 (Analog) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 11 (Accelerometer) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 12 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 13 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 14 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 15 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 16 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 17 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 18 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 19 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 20 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 21 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 22 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 23 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 24 (RFID) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 25 (RFID) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 26 (RFID) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 27 (RFID) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 28 (RFID) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 29 (LED) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 30 (LED) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 31 (LED) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 32 (GPS) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 33 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 34 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 35 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 36 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 37 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 38 (Bridge) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 39 (Bridge) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 40 (Encoder) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 41 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 42 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 43 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 44 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 45 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 46 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 47 (Encoder) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 48 (Encoder) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 49 (Encoder) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 50 (Accelerometer) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 51 (FrequencyCounter) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 52 (IR) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 53 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 54 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 55 (Encoder) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 56 (PHSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 57 (Accelerometer) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 58 (MotorControl) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 59 (AdvancedServo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 60 (AdvancedServo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 61 (AdvancedServo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 62 (Stepper) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 63 (Stepper) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 64 (MotorControl) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 65 (MotorControl) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 66 (AdvancedServo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 67 (Stepper) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 68 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 69 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 70 (TextLCD) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 71 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 72 (TextLCD) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 73 (TextLCD) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 74 (TextLCD) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 75 (TextLCD) */
	{ sendDIGITALINPUT_PORT, recvDIGITALINPUT_PORT },	/* 76 (VINT) */
	{ sendDIGITALOUTPUT_PORT, recvDIGITALOUTPUT_PORT },	/* 77 (VINT) */
	{ sendVOLTAGEINPUT_PORT, recvVOLTAGEINPUT_PORT },	/* 78 (VINT) */
	{ sendVOLTAGERATIOINPUT_PORT, recvVOLTAGERATIOINPUT_PORT },	/* 79 (VINT) */
	{ sendADP1000, recvADP1000 },	/* 80 (VINT) */
	{ sendADP1001, recvADP1001 },	/* 81 (VINT) */
	{ sendDAQ1000, recvDAQ1000 },	/* 82 (VINT) */
	{ sendOUT1000, recvOUT1000 },	/* 83 (VINT) */
	{ sendOUT1001, recvOUT1001 },	/* 84 (VINT) */
	{ sendOUT1002, recvOUT1002 },	/* 85 (VINT) */
	{ sendDAQ1200, recvDAQ1200 },	/* 86 (VINT) */
	{ sendOUT1100, recvOUT1100 },	/* 87 (VINT) */
	{ sendDAQ1300, recvDAQ1300 },	/* 88 (VINT) */
	{ sendDAQ1301, recvDAQ1301 },	/* 89 (VINT) */
	{ sendDAQ1400, recvDAQ1400 },	/* 90 (VINT) */
	{ sendDAQ1500, recvDAQ1500 },	/* 91 (VINT) */
	{ sendVCP1100, recvVCP1100 },	/* 92 (VINT) */
	{ sendDCC1000, recvDCC1000 },	/* 93 (VINT) */
	{ sendDCC1000_POSITIONCONTROL, recvDCC1000_POSITIONCONTROL },	/* 94 (VINT) */
	{ sendDCC1001, recvDCC1001 },	/* 95 (VINT) */
	{ sendDCC1100, recvDCC1100 },	/* 96 (VINT) */
	{ sendDST1000, recvDST1000 },	/* 97 (VINT) */
	{ sendDST1200, recvDST1200 },	/* 98 (VINT) */
	{ sendENC1000, recvENC1000 },	/* 99 (VINT) */
	{ sendHIN1101, recvHIN1101 },	/* 100 (VINT) */
	{ sendHIN1000, recvHIN1000 },	/* 101 (VINT) */
	{ sendHIN1001, recvHIN1001 },	/* 102 (VINT) */
	{ sendHIN1100, recvHIN1100 },	/* 103 (VINT) */
	{ sendHUM1000, recvHUM1000 },	/* 104 (VINT) */
	{ sendLCD1100, recvLCD1100 },	/* 105 (VINT) */
	{ sendLED1000, recvLED1000 },	/* 106 (VINT) */
	{ sendLUX1000, recvLUX1000 },	/* 107 (VINT) */
	{ sendMOT1100_OLD, recvMOT1100_OLD },	/* 108 (VINT) */
	{ sendMOT1100, recvMOT1100 },	/* 109 (VINT) */
	{ sendMOT1101, recvMOT1101 },	/* 110 (VINT) */
	{ sendPRE1000, recvPRE1000 },	/* 111 (VINT) */
	{ sendRCC1000, recvRCC1000 },	/* 112 (VINT) */
	{ sendVINTSERVO_S2313M, recvVINTSERVO_S2313M },	/* 113 (VINT) */
	{ sendVINTSERVO_S3317M, recvVINTSERVO_S3317M },	/* 114 (VINT) */
	{ sendVINTSERVO_S4309M, recvVINTSERVO_S4309M },	/* 115 (VINT) */
	{ sendVINTSERVO_S4309R, recvVINTSERVO_S4309R },	/* 116 (VINT) */
	{ sendREL1000, recvREL1000 },	/* 117 (VINT) */
	{ sendREL1100, recvREL1100 },	/* 118 (VINT) */
	{ sendREL1101, recvREL1101 },	/* 119 (VINT) */
	{ sendSAF1000, recvSAF1000 },	/* 120 (VINT) */
	{ sendSND1000, recvSND1000 },	/* 121 (VINT) */
	{ sendSTC1000, recvSTC1000 },	/* 122 (VINT) */
	{ sendSTC1001, recvSTC1001 },	/* 123 (VINT) */
	{ sendTMP1000, recvTMP1000 },	/* 124 (VINT) */
	{ sendTMP1100, recvTMP1100 },	/* 125 (VINT) */
	{ sendTMP1101, recvTMP1101 },	/* 126 (VINT) */
	{ sendTMP1200, recvTMP1200 },	/* 127 (VINT) */
	{ sendTMP1300, recvTMP1300 },	/* 128 (VINT) */
	{ sendVCP1000, recvVCP1000 },	/* 129 (VINT) */
	{ sendVCP1001, recvVCP1001 },	/* 130 (VINT) */
	{ sendVCP1002, recvVCP1002 },	/* 131 (VINT) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 132 (Hub) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 133 (Hub) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 134 (MeshDongle) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 135 (Hub) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 136 (Hub) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 137 (FirmwareUpgrade) */
	{ sendFIRMWARE_UPGRADE_STM32F0, recvFIRMWARE_UPGRADE_STM32F0 },	/* 138 (VINT) */
	{ sendFIRMWARE_UPGRADE_STM8S, recvFIRMWARE_UPGRADE_STM8S },	/* 139 (VINT) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 140 (FirmwareUpgrade) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 141 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 142 (InterfaceKit) */
	{ sendGENERICVINT, recvGENERICVINT },	/* 143 (VINT) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 144 (Dictionary) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 145 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 146 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 147 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 148 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 149 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 150 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 151 (Generic) */
	{ NULL, NULL }
};

==> libphidget22-1.0.0.20180327.tar.gz: libphidget22-1.0.0.20180327/src/vintpackets.gen.c <==

static const VINTIO_t VINTIO[] = {
	{ _sendDEFAULT, _recvDEFAULT },	/* 0 */
	{ _sendDEFAULT, _recvDEFAULT },	/* 1 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 2 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 3 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 4 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 5 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 6 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 7 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 8 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 9 (Servo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 10 (Analog) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 11 (Accelerometer) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 12 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 13 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 14 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 15 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 16 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 17 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 18 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 19 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 20 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 21 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 22 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 23 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 24 (RFID) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 25 (RFID) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 26 (RFID) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 27 (RFID) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 28 (RFID) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 29 (LED) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 30 (LED) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 31 (LED) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 32 (GPS) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 33 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 34 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 35 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 36 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 37 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 38 (Bridge) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 39 (Bridge) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 40 (Encoder) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 41 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 42 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 43 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 44 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 45 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 46 (TemperatureSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 47 (Encoder) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 48 (Encoder) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 49 (Encoder) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 50 (Accelerometer) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 51 (FrequencyCounter) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 52 (IR) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 53 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 54 (Spatial) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 55 (Encoder) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 56 (PHSensor) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 57 (Accelerometer) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 58 (MotorControl) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 59 (AdvancedServo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 60 (AdvancedServo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 61 (AdvancedServo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 62 (Stepper) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 63 (Stepper) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 64 (MotorControl) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 65 (MotorControl) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 66 (AdvancedServo) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 67 (Stepper) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 68 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 69 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 70 (TextLCD) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 71 (InterfaceKit) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 72 (TextLCD) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 73 (TextLCD) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 74 (TextLCD) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 75 (TextLCD) */
	{ sendDIGITALINPUT_PORT, recvDIGITALINPUT_PORT },	/* 76 (VINT) */
	{ sendDIGITALOUTPUT_PORT, recvDIGITALOUTPUT_PORT },	/* 77 (VINT) */
	{ sendVOLTAGEINPUT_PORT, recvVOLTAGEINPUT_PORT },	/* 78 (VINT) */
	{ sendVOLTAGERATIOINPUT_PORT, recvVOLTAGERATIOINPUT_PORT },	/* 79 (VINT) */
	{ sendADP1000, recvADP1000 },	/* 80 (VINT) */
	{ sendADP1001, recvADP1001 },	/* 81 (VINT) */
	{ sendDAQ1000, recvDAQ1000 },	/* 82 (VINT) */
	{ sendOUT1000, recvOUT1000 },	/* 83 (VINT) */
	{ sendOUT1001, recvOUT1001 },	/* 84 (VINT) */
	{ sendOUT1002, recvOUT1002 },	/* 85 (VINT) */
	{ sendDAQ1200, recvDAQ1200 },	/* 86 (VINT) */
	{ sendOUT1100, recvOUT1100 },	/* 87 (VINT) */
	{ sendDAQ1300, recvDAQ1300 },	/* 88 (VINT) */
	{ sendDAQ1301, recvDAQ1301 },	/* 89 (VINT) */
	{ sendDAQ1400, recvDAQ1400 },	/* 90 (VINT) */
	{ sendDAQ1500, recvDAQ1500 },	/* 91 (VINT) */
	{ sendVCP1100, recvVCP1100 },	/* 92 (VINT) */
	{ sendDCC1000, recvDCC1000 },	/* 93 (VINT) */
	{ sendDCC1000_POSITIONCONTROL, recvDCC1000_POSITIONCONTROL },	/* 94 (VINT) */
	{ sendDCC1001, recvDCC1001 },	/* 95 (VINT) */
	{ sendMCSML1, recvMCSML1 },	/* 96 (VINT) */
	{ sendDCC1100, recvDCC1100 },	/* 97 (VINT) */
	{ sendDST1000, recvDST1000 },	/* 98 (VINT) */
	{ sendDST1200, recvDST1200 },	/* 99 (VINT) */
	{ sendENC1000, recvENC1000 },	/* 100 (VINT) */
	{ sendHIN1101, recvHIN1101 },	/* 101 (VINT) */
	{ sendHIN1000, recvHIN1000 },	/* 102 (VINT) */
	{ sendHIN1001, recvHIN1001 },	/* 103 (VINT) */
	{ sendHIN1100, recvHIN1100 },	/* 104 (VINT) */
	{ sendHUM1000, recvHUM1000 },	/* 105 (VINT) */
	{ sendLCD1100, recvLCD1100 },	/* 106 (VINT) */
	{ sendLED1000, recvLED1000 },	/* 107 (VINT) */
	{ sendLUX1000, recvLUX1000 },	/* 108 (VINT) */
	{ sendMOT1100_OLD, recvMOT1100_OLD },	/* 109 (VINT) */
	{ sendMOT1100, recvMOT1100 },	/* 110 (VINT) */
	{ sendMOT1101, recvMOT1101 },	/* 111 (VINT) */
	{ sendPRE1000, recvPRE1000 },	/* 112 (VINT) */
	{ sendRCC1000, recvRCC1000 },	/* 113 (VINT) */
	{ sendVINTSERVO_S2313M, recvVINTSERVO_S2313M },	/* 114 (VINT) */
	{ sendVINTSERVO_S3317M, recvVINTSERVO_S3317M },	/* 115 (VINT) */
	{ sendVINTSERVO_S4309M, recvVINTSERVO_S4309M },	/* 116 (VINT) */
	{ sendVINTSERVO_S4309R, recvVINTSERVO_S4309R },	/* 117 (VINT) */
	{ sendREL1000, recvREL1000 },	/* 118 (VINT) */
	{ sendREL1100, recvREL1100 },	/* 119 (VINT) */
	{ sendREL1101, recvREL1101 },	/* 120 (VINT) */
	{ sendSAF1000, recvSAF1000 },	/* 121 (VINT) */
	{ sendSND1000, recvSND1000 },	/* 122 (VINT) */
	{ sendSTC1000, recvSTC1000 },	/* 123 (VINT) */
	{ sendSTC1001, recvSTC1001 },	/* 124 (VINT) */
	{ sendTMP1000, recvTMP1000 },	/* 125 (VINT) */
	{ sendTMP1100, recvTMP1100 },	/* 126 (VINT) */
	{ sendTMP1101, recvTMP1101 },	/* 127 (VINT) */
	{ sendTMP1200, recvTMP1200 },	/* 128 (VINT) */
	{ sendTMP1300, recvTMP1300 },	/* 129 (VINT) */
	{ sendVCP1000, recvVCP1000 },	/* 130 (VINT) */
	{ sendVCP1001, recvVCP1001 },	/* 131 (VINT) */
	{ sendVCP1002, recvVCP1002 },	/* 132 (VINT) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 133 (Hub) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 134 (Hub) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 135 (MeshDongle) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 136 (Hub) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 137 (Hub) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 138 (FirmwareUpgrade) */
	{ sendFIRMWARE_UPGRADE_STM32F0, recvFIRMWARE_UPGRADE_STM32F0 },	/* 139 (VINT) */
	{ sendFIRMWARE_UPGRADE_STM8S, recvFIRMWARE_UPGRADE_STM8S },	/* 140 (VINT) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 141 (FirmwareUpgrade) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 142 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 143 (InterfaceKit) */
	{ sendGENERICVINT, recvGENERICVINT },	/* 144 (VINT) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 145 (Dictionary) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 146 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 147 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 148 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 149 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 150 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 151 (Generic) */
	{ _sendDEFAULT, _recvDEFAULT },	/* 152 (Generic) */
	{ NULL, NULL }
};
